summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/skymapdraw.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/skymapdraw.cpp')
-rw-r--r--kstars/kstars/skymapdraw.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kstars/kstars/skymapdraw.cpp b/kstars/kstars/skymapdraw.cpp
index 8b15c57a..0c76de4b 100644
--- a/kstars/kstars/skymapdraw.cpp
+++ b/kstars/kstars/skymapdraw.cpp
@@ -15,7 +15,7 @@
* *
***************************************************************************/
//This file contains drawing functions SkyMap class.
#include <stdlib.h> // abs
#include <math.h> //log10()
@@ -1578,7 +1578,7 @@ void SkyMap::drawPlanetTrail( TQPainter& psky, KSPlanetBase *ksp, double scale )
if ( ( o.x() >= -1000 && o.x() <= Width+1000 && o.y() >=-1000 && o.y() <= Height+1000 ) ) {
//Want to disable line-drawing if this point and the last are both outside bounds of display.
- if ( ! rect().contains( o ) && ! rect().contains( cur ) ) doDrawLine = false;
+ if ( ! rect().tqcontains( o ) && ! rect().tqcontains( cur ) ) doDrawLine = false;
cur = o;
if ( doDrawLine ) {
@@ -15,7 +15,7 @@
* *
***************************************************************************/
-//This file contains drawing functions SkyMap class.
+//This file tqcontains drawing functions SkyMap class.
#include <stdlib.h> // abs
#include <math.h> //log10()